package it.cavallium.strangedb.database.io;

import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.file.Path;

public class SimpleMultiFileIO implements IMultiFileIO {

	public final int filesCount;
	private final SimpleFileReaderWriter[] fileRW;

	public SimpleMultiFileIO(Path dataFile, int filesCount) throws IOException {
		this.filesCount = filesCount;
		String fileName = dataFile.toFile().getName();

		fileRW = new SimpleFileReaderWriter[filesCount];

		for (int i = 0; i < filesCount; i++) {
			fileRW[i] = new SimpleFileReaderWriter(dataFile.resolveSibling(ExtensionUtils.insertExtension(fileName, i)));
		}
	}

	@Override
	public int getFilesCount() {
		return filesCount;
	}

	@Override
	public ByteBuffer readAt(int fileIndex, long index, int length) throws IOException {
		return fileRW[fileIndex].readAt(index, length);
	}

	@Override
	public int writeAt(int fileIndex, long index, int length, ByteBuffer data) throws IOException {
		return fileRW[fileIndex].writeAt(index, length, data);
	}

	@Override
	public long writeAtEnd(int fileIndex, int length, ByteBuffer data) throws IOException {
		return fileRW[fileIndex].writeAtEnd(length, data);
	}

	@Override
	public void close() throws IOException {
		for (SimpleFileReaderWriter file : fileRW) {
			file.close();
		}
	}
}
